# AFGL (1986) data files

The tables were extracted from the following published technical report:

Anderson, G. P., S. A. Clough, F. X. Kneizys, J. H. Chetwynd, and E. P. Shettle. 1986. ‘AFGL Atmospheric Constituent Profiles (0.120km)’. AFGL-TR-0208 Environemental Research Papers, May. [http://adsabs.harvard.edu/abs/1986afgl.rept.....A](http://adsabs.harvard.edu/abs/1986afgl.rept.....A).
